MTfit.extensions.scatangle
==========================


.. literalinclude:: ../../src/MTfit/extensions/scatangle.py


There are also Cython functions:

.. literalinclude:: ../../src/MTfit/extensions/cscatangle.pyx
    :language: cython